<?php
namespace Service;

use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\ORM\DateTime;

use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class ErpService extends \Zeedhi\Framework\Controller\Simple {

    protected $connection;
    protected $entityManager;

    public function __construct(\Doctrine\ORM\EntityManager $entityManager)  {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }
    
    /**
     * EXPORTA_FORNECEDOR
     * EXPORTA_CLIENTE
     * EXPORTA_NOTAFISCAL_ENTRADA
     * EXPORTA_NOTAFISCAL_SAIDA
     */
     
    const TEST_CONNECTION = "SELECT CDEMPRESA, NMEMPRESA FROM EMPRESA";
    public function testConnection(){
        try {
            $params = array();
            return $this->entityManager->getConnection()->fetchAll(self::TEST_CONNECTION, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    const GET_SEQ_LOG = "SELECT NVL(MAX(SEQLOG)+1, 1) AS SEQLOG FROM USR_PROT_INTEGRACAO";
    public function getSeqLog(){
        try {
            $params = array();
            return $this->entityManager->getConnection()->fetchAll(self::GET_SEQ_LOG, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    const BUSCA_FILIAL_PRODUTO = "SELECT F.CDFILIAL
                                    FROM FILIAL F, PARAMFILIAL P
                                WHERE F.CDFILIAL = P.CDFILIAL
                                AND CDEXFILIAL = :P_CDEXFILIAL";
    public function buscaFilialProduto($cdexfilial){
        try {
            $params = array(
                'P_CDEXFILIAL'    => $cdexfilial
            );
            return $this->entityManager->getConnection()->fetchAll(self::BUSCA_FILIAL_PRODUTO, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /* INICIO METODOS DE UPDATE DATA DE EXPORTAÇÃO */
    /* PRODUTO */
    
    public function UpdateProduto($cdarvprod){
        try {
             $update =  "UPDATE PRODUTO SET SYSTAX_DTEXPXML = SYSDATE WHERE CDARVPROD = '".$cdarvprod."'";
            return $this->entityManager->getConnection()->executeQuery($update, []);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function UpdateEnviaProdXml($cdarvprodini, $cdarvprodfin){
        try {
             $update =  "UPDATE ENVIA_PROD_XML SET DTEXPORTA = SYSDATE WHERE CDPRODUTOINI = '".$cdarvprodini.'\''. " AND CDPRODUTOFIN = '".$cdarvprodfin.'\'';
            return $this->entityManager->getConnection()->executeQuery($update, []);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    const BUSCAL_PRODUTO = "SELECT CDPRODUTO
                              FROM PRODUTO
                             WHERE CDARVPROD = :P_CDARVPROD";
    public function insere_log_prod_xml($cdarvprod, $mensagem, $id, $codigo){
        try {
            $params = array('P_CDARVPROD' => $cdarvprod);
            $produto = $this->entityManager->getConnection()->fetchAll(self::BUSCAL_PRODUTO, $params);

    		$cdproduto = $produto[0]['CDPRODUTO'];
    		
            $params = array(
                'P_CDPRODUTO' => $cdproduto,
                'P_MENSAGEM'  => $mensagem,
                'P_ID'        => $id,
                'P_CODIGO'    => $codigo
            );
            
            $insert = "INSERT INTO LOG_ENVIA_PROD_XML(CDPRODUTO, MENSAGEM, ID, CODIGO)
                       VALUES(:P_CDPRODUTO, :P_MENSAGEM, :P_ID, :P_CODIGO)";
    		
            return $this->entityManager->getConnection()->executeQuery($insert, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /* FORNECEDOR */
    const UPDATE_FORNECEDOR_EXP = "UPDATE FORNECEDOR
                                      SET DTEXPXMLPROT = SYSDATE
                                    WHERE CDFORNECED = :P_CDFORNECED";
    public function updateFornecedorExp($paramsFornecedor){
        try {
            
            $params = array(
                'P_CDFORNECED'   => $paramsFornecedor['CDFORNECED']
            );
            
            return $this->entityManager->getConnection()->executeQuery(self::UPDATE_FORNECEDOR_EXP, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /* CLIENTE */
    const UPDATE_CLIENTE_EXP = "UPDATE CLIENTE
                                      SET DTEXPXMLPROT = SYSDATE
                                    WHERE CDCLIENTE = :P_CDCLIENTE";
    public function updateClienteExp($paramsCliente){
        try {
            
            $params = array(
                'P_CDCLIENTE'   => $paramsCliente['CDCLIENTE']
            );
            
            return $this->entityManager->getConnection()->executeQuery(self::UPDATE_CLIENTE_EXP, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /* NFE */
    const UPDATE_NFE_EXP = "UPDATE ITEMPRODUTO
                              SET DTEXPXMLPROT = SYSDATE
                            WHERE CDFILIAL    = :P_CDFILIAL
                              AND NRLANCTONF  = :P_NRLANCTONF";
    public function updateNFEExp($paramsNFE){
        try {
            
            $params = array(
                'P_CDFILIAL'    => $paramsNFE['CDFILIAL'],
                'P_NRLANCTONF'  => $paramsNFE['NRLANCTONF']
            );
            
            return $this->entityManager->getConnection()->executeQuery(self::UPDATE_NFE_EXP, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /* ESTOQUE */
    const UPDATE_ESTOQUE_EXP = "UPDATE ITLANCTOEST
                                   SET DTEXPXMLPROT = SYSDATE
                                 WHERE NRLANCESTQ = :P_NRLANCESTQ
                                   AND CDFILIAL   = :P_CDFILIAL";
    public function updateEstoqueExp($paramsEstoque){
        try {
            
            $params = array(
                'P_CDFILIAL'    => $paramsEstoque['CDFILIAL'],
                'P_NRLANCESTQ'  => $paramsEstoque['NRLANCESTQ']
            );
            
            return $this->entityManager->getConnection()->executeQuery(self::UPDATE_ESTOQUE_EXP, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /* FIM METODOS DE UPDATE DATA DE EXPORTAÇÃO */
    
    const GERA_LOG = "INSERT INTO USR_PROT_INTEGRACAO(
                            SEQLOG, CDLOG, XMLLOG, OBSLOG, CDFORNECED, CDPRODUTO, CDFILIAL, 
                            NRLANCTONF, NRLANCESTQ, CDCLIENTE, IDACAO, IDEXIBE, IDTIPINTEGR
                        )VALUES(
                            :P_SEQLOG, :P_CDLOG, :P_XMLLOG, :P_OBSLOG, :P_CDFORNECED, :P_CDPRODUTO, :P_CDFILIAL, 
                            :P_NRLANCTONF, :P_NRLANCESTQ, :P_CDCLIENTE, :P_IDACAO, :P_IDEXIBE, :P_IDTIPINTEGR
                        )";
    public function geraLog($paramsLog){
        try {
            
            $seqlog = $this->getSeqLog();
            
            $params = array(
                'P_SEQLOG'      => $seqlog[0]['SEQLOG'],
                'P_CDLOG'       => $paramsLog['CDLOG'],
                'P_XMLLOG'      => $paramsLog['XMLLOG'],
                'P_OBSLOG'      => $paramsLog['OBSLOG'],
                'P_CDFORNECED'  => $paramsLog['CDFORNECED'],
                'P_CDPRODUTO'   => $paramsLog['CDPRODUTO'],
                'P_CDFILIAL'    => $paramsLog['CDFILIAL'],
                'P_NRLANCTONF'  => $paramsLog['NRLANCTONF'],
                'P_NRLANCESTQ'  => $paramsLog['NRLANCESTQ'],
                'P_CDCLIENTE'   => $paramsLog['CDCLIENTE'],
                'P_IDACAO'      => $paramsLog['IDACAO'],
                'P_IDEXIBE'     => $paramsLog['IDEXIBE'],
                'P_IDTIPINTEGR' => $paramsLog['IDTIPINTEGR']
            );
            
            return $this->entityManager->getConnection()->executeQuery(self::GERA_LOG, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
     
    const EXPORTA_FORNECEDOR = "SELECT * FROM USR_PROT_FORNECEDOR";
    
    const EXPORTA_CLIENTE = "SELECT * FROM USR_PROT_CLIENTE";
    
    const EXPORTA_NOTAFISCAL_ENTRADA  = "SELECT * FROM USR_PROT_NFENTRADA";
                                        
    const EXPORTA_ITENS_NFE =   "SELECT * FROM USR_PROT_ITEMENTRADA
                                WHERE NRLANCTONF = :P_NRLANCTONF
                                  AND CDFILIAL = :P_CDFILIAL";

    const EXPORTA_NOTAFISCAL_SAIDA = "SELECT * FROM USR_PROT_NFSAIDA";
    
    const EXPORTA_ITENS_NFS   = "SELECT * FROM USR_PROT_ITEMSAIDA
                                WHERE NRLANCTONF = :P_NRLANCTONF
                                  AND CDFILIAL = :P_CDFILIAL";
                                

    
                                
    const EXPORTA_ESTOQUE = "SELECT DISTINCT * FROM USR_PROT_LANCTOESTOQ";
    
    const EXPORTA_ITENS_ESTOQUE   = "SELECT * FROM USR_PROT_ITLANCTOEST
                                WHERE NRLANCESTQ = :P_NRLANCESTQ
                                AND CDFILIAL = :P_CDFILIAL";
    
    /**
     *  Procedures para popular tabelas de exportação
     *      callProcedurePROT_EXPORTA_FORNECEDOR    -> USR_PROT_FORNECEDOR
     *      callProcedurePROT_EXPORTA_CLIENTE       -> USR_PROT_CLIENTE
     *      callProcedurePROT_EXPORTA_NFENTRADA     -> USR_PROT_NFENTRADA   / USR_PROT_ITEMENTRADA
     *      callProcedurePROT_EXPORTA_NFSAIDA       -> USR_PROT_NFSAIDA     / USR_PROT_ITEMSAIDA
     *      callProcedurePROT_EXPORTA_PRODUTO       -> USR_PROT_PRODUTO
     *      callProcedurePROT_EXPORTA_POS_ESTOQUE   -> USR_PROT_LANCTOESTOQ / USR_PROT_ITLANCTOEST
     */
    public function callProcedurePROT_EXPORTA_FORNECEDOR(){
        try{
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'PROT_EXPORTA_FORNECEDOR');
            return $procedure->execute();
        }catch(\Exception $e){
            return $e->getMessage();
        }
    }

    public function callProcedurePROT_EXPORTA_CLIENTE(){
        try{
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'PROT_EXPORTA_CLIENTE');
            return $procedure->execute();
        }catch(\Exception $e){
            return $e->getMessage();
        }
    }

    public function callProcedurePROT_EXPORTA_NFENTRADA(){
        try{
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'PROT_EXPORTA_NFENTRADA');
            return $procedure->execute();
        }catch(\Exception $e){
            return $e->getMessage();
        }
    }

    public function callProcedurePROT_EXPORTA_NFSAIDA(){
        try{
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'PROT_EXPORTA_NFSAIDA');
            return $procedure->execute();
        }catch(\Exception $e){
            return $e->getMessage();
        }
    }
    
    public function callProcedureEXPORTA_PRODUTO_XML(){
        try{
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'EXPORTA_PRODUTO_XML');
            return $procedure->execute();
        }catch(\Exception $e){
            return $e->getMessage();
        }
    }
    
    public function callProcedurePROT_EXPORTA_POS_ESTOQUE(){
        try{
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'PROT_EXPORTA_POS_ESTOQUE');
            return $procedure->execute();
        }catch(\Exception $e){
            return $e->getMessage();
        }
    }
    
    /**
     *  Retorna Fornecedores para o método "EnviarFornecedor".
     */
    public function retornaFornecedor() {
        try {
            $params = array();
            return $this->entityManager->getConnection()->fetchAll(self::EXPORTA_FORNECEDOR, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     *  Retorna Clientes para o método "EnviarCliente".
     */
    public function retornaCliente() {
        try {
            $params = array();
            return $this->entityManager->getConnection()->fetchAll(self::EXPORTA_CLIENTE, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     *  Retorna Notas Fiscais de Entrada para o método "EnviarNotaFiscalEntrada".
     */
    public function retornaNFE() {
        try {
            $params = array();
            return $this->entityManager->getConnection()->fetchAll(self::EXPORTA_NOTAFISCAL_ENTRADA, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     *  Retorna Itens das Notas Fiscais de Entrada para o método "EnviarNotaFiscalEntrada".
     */
    public function retornaItensNFE($cdfilial, $nrlanctonf) {
        try {
            $params = array(
                'P_NRLANCTONF' => $nrlanctonf,
                'P_CDFILIAL' => $cdfilial
            );
            return $this->entityManager->getConnection()->fetchAll(self::EXPORTA_ITENS_NFE, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     *  Retorna Notas Fiscais de Saída para o método "EnviarNotaFiscalSaida".
     */
    public function retornaNFS() {
        try {
            $params = array();
            return $this->entityManager->getConnection()->fetchAll(self::EXPORTA_NOTAFISCAL_SAIDA, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     *  Retorna Itens das Notas Fiscais de Saida para o método "EnviarNotaFiscalSaida".
     */
    public function retornaItensNFS($cdfilial, $nrlanctonf) {
        try {
            $params = array(
                'P_NRLANCTONF' => $nrlanctonf,
                'P_CDFILIAL' => $cdfilial
            );
            return $this->entityManager->getConnection()->fetchAll(self::EXPORTA_ITENS_NFS, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    
    /**
     *  Retorna Produtos para o método "EnviarProduto".
     */
    public function retornaProduto() {
        try {
            $params = array();
            $query = "SELECT ARQ_XML, CDPRODUTOINI, CDPRODUTOFIN FROM ENVIA_PROD_XML WHERE DTEXPORTA IS NULL";
            $resultado = $this->entityManager->getConnection()->fetchAll($query, $params);
            return $resultado;
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     *  Retorna Lançamentos de estoque para o método "EnviarEstoque".
     */
    public function retornaEstoque() {
        try {
            $params = array();
            return $this->entityManager->getConnection()->fetchAll(self::EXPORTA_ESTOQUE, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     *  Retorna Itens dos Lançamentos de estoque para o método "EnviarEstoque".
     */
    public function retornaItensEstoque($nrlancestq, $cdfilial) {
        try {
            $params = array(
                'P_NRLANCESTQ'  => $nrlancestq,
                'P_CDFILIAL'    => $cdfilial
            );
            return $this->entityManager->getConnection()->fetchAll(self::EXPORTA_ITENS_ESTOQUE, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function validaCallProcedure($operation){
        try{
            switch ($operation) {
    			case 'FORNECEDOR':
    				$this->entityManager->getConnection()->executeQuery(
    				    "DELETE FROM USR_PROT_FORNECEDOR", array() 
    				);
    				break;
    				
    			case 'CLIENTE':
    				$this->entityManager->getConnection()->executeQuery(
    				    "DELETE FROM USR_PROT_CLIENTE", array() 
    				);
    				break;
    				
    			case 'NFE':
    				$this->entityManager->getConnection()->executeQuery(
    				    "DELETE FROM USR_PROT_NFENTRADA", array()
    				);
    				$this->entityManager->getConnection()->executeQuery(
    				    "DELETE FROM USR_PROT_ITEMENTRADA", array()
    				);
    				break;
    				
    			case 'NFS':
    				$this->entityManager->getConnection()->executeQuery(
    				    "DELETE FROM USR_PROT_NFSAIDA", array()
    				);
    				$this->entityManager->getConnection()->executeQuery(
    				    "DELETE FROM USR_PROT_ITEMSAIDA", array()
    				);
    				break;
    			
    			case 'PRODUTO':
    				$this->entityManager->getConnection()->executeQuery(
    				    "DELETE FROM USR_PROT_PRODUTO", array() 
    				);
    				break;
    			
    			default:
    				// code...
    				break;
    		}
        }catch(\Exception $e){
            return $e->getMessage();
        }
    }
 
    public function insere_imp_systax($imposto, $cenario, $cod_prod, $cst, $nrseqimp, $bc_compos, $aliquota, $p_red_bd, $vig_de, $vig_ate, $dispositivo, $observacao,$infoAdic, $cenq, $paramsUfDest, $ori_prod){
        try {
           
            if($vig_de) {
                $date = new \DateTime($vig_de);
                $vig_de = $date->format('d/m/Y');
            }
            if($vig_ate) {
                $date = new \DateTime($vig_ate);
                $vig_ate = $date->format('d/m/Y');
            }
           
            $params = array(
                'P_ID_CENARIO'  => $cenario,
                'P_COD_PROD'    => $cod_prod,
                'P_CST'         => $cst,
                'P_NRSEQIMP'    => $nrseqimp,
                'P_BC_COMPOS'   => $bc_compos,
                'P_ALIQUOTA'    => $aliquota,
                'P_P_RED_BC'    => $p_red_bd,
                'P_VIG_DE'      => $vig_de,
                'P_VIG_ATE'     => $vig_ate, 
                'P_DISPOSITIVO' => $dispositivo, 
                'P_OBSERVACAO'  => $observacao,
                'P_INFO_ADICIONAIS' => $infoAdic,
                'P_ORI_PROD'    => $ori_prod
            );
            
            $sqlVigDe = $vig_de ? "TO_DATE(:P_VIG_DE, 'DD/MM/YYYY')," : ":P_VIG_DE,";
            $sqlVigAte = $vig_ate ? "TO_DATE(:P_VIG_ATE, 'DD/MM/YYYY')" : ":P_VIG_ATE";
            
            if($imposto == 'SYS_IPI') {
                $params["P_CENQ"] = $cenq;
                $insert = "INSERT INTO ".$imposto."(ID_CENARIO, COD_PROD, CST, NRSEQIMP, BC_COMPOS, ALIQUOTA, P_RED_BC, VIG_DE, VIG_ATE, DISPOSITIVO, OBSERVACAO, CENQ, INF_ADICIONAIS, ORIG_PROD)
                       VALUES(:P_ID_CENARIO, :P_COD_PROD, :P_CST, :P_NRSEQIMP, :P_BC_COMPOS, :P_ALIQUOTA, :P_P_RED_BC,". $sqlVigDe . $sqlVigAte . ", :P_DISPOSITIVO, :P_OBSERVACAO, :P_CENQ , :P_INFO_ADICIONAIS, :P_ORI_PROD)";
            
            }
            else if($imposto == 'SYS_ICMSST') {
                unset($params["P_INFO_ADICIONAIS"]);
                $insert = "INSERT INTO ".$imposto."(ID_CENARIO, COD_PROD,  NRSEQIMP, BC_COMPOSICAO, ALIQUOTA_ST, P_RED_BC_ST, VIG_DE, VIG_ATE, DISPOSITIVO, OBSERVACAO, ORIG_PROD)
                       VALUES(:P_ID_CENARIO, :P_COD_PROD, :P_NRSEQIMP, :P_BC_COMPOS, :P_ALIQUOTA, :P_P_RED_BC,". $sqlVigDe . $sqlVigAte . ", :P_DISPOSITIVO, :P_OBSERVACAO, :P_ORI_PROD)";
            
                
            }else if ($imposto == 'SYS_ICMS' && $paramsUfDest != null){
                
                if($paramsUfDest[":P_VIG_DE_UF_DEST"]) {
                    $date = new \DateTime($paramsUfDest[":P_VIG_DE_UF_DEST"]);
                    $paramsUfDest[":P_VIG_DE_UF_DEST"] = $date->format('d/m/Y');
                }
                if($paramsUfDest[":P_VIG_ATE_UF_DEST"]) {
                    $date = new \DateTime($paramsUfDest[":P_VIG_ATE_UF_DEST"]);
                    $paramsUfDest[":P_VIG_ATE_UF_DEST"] = $date->format('d/m/Y');
                }
                
                $params = array_merge($params, $paramsUfDest);

                $sqlVigDeUfDestino = ($paramsUfDest[":P_VIG_DE_UF_DEST"]) ? " TO_DATE(:P_VIG_DE_UF_DEST, 'DD/MM/YYYY')," : " :P_VIG_DE_UF_DEST,";
                $sqlVigAteUfDestino = ($paramsUfDest[":P_VIG_ATE_UF_DEST"]) ? "TO_DATE(:P_VIG_ATE_UF_DEST, 'DD/MM/YYYY')" : " :P_VIG_ATE_UF_DEST";
                
                $insert = "INSERT INTO ".$imposto."(ID_CENARIO, COD_PROD, CST, NRSEQIMP, BC_COMPOS, ALIQUOTA, P_RED_BC, VIG_DE, VIG_ATE, DISPOSITIVO, OBSERVACAO, INF_ADICIONAIS, 
                                                    CST_UF_DEST, ALIQ_UF_DEST, BC_COMP_UF_DEST, BC_COMP_FCP_UF_DEST, ALIQ_INT_UF_DEST, FCP_UF_DEST, 
                                                    PERC_PART_UF_DEST, VR_PAUTA_UF_DEST,UN_PAUTA_UF_DEST, GENERICO_UF_DEST, VIG_DE_UF_DEST, VIG_ATE_UF_DEST,
                                                    DISP_LEGAL_UF_DEST,OBSERV_UF_DEST, RED_BC_ST_UF_DEST, ORIG_PROD)
                       VALUES(:P_ID_CENARIO, :P_COD_PROD, :P_CST, :P_NRSEQIMP, :P_BC_COMPOS, :P_ALIQUOTA, :P_P_RED_BC,". $sqlVigDe . $sqlVigAte . ", :P_DISPOSITIVO, :P_OBSERVACAO, :P_INFO_ADICIONAIS, 
                            :P_CST_UF_DEST, :P_ALIQ_UF_DEST, :P_BC_COMP_UF_DEST, :P_BC_COMP_FCP_UF_DEST , :P_ALIQ_INT_UF_DEST, :P_FCP_UF_DEST,
                            :P_PERC_PART_UF_DEST, :P_VR_PAUTA_UF_DEST, :P_UN_PAUTA_UF_DEST, :P_GENERICO_UF_DEST, ". $sqlVigDeUfDestino . $sqlVigAteUfDestino . ",
                            :P_DISP_LEGAL_UF_DEST, :P_OBSERV_UF_DEST, :P_RED_BC_ST_UF_DEST, :P_ORI_PROD)";
 
            }
            else{
                   $insert = "INSERT INTO ".$imposto."(ID_CENARIO, COD_PROD, CST, NRSEQIMP, BC_COMPOS, ALIQUOTA, P_RED_BC, VIG_DE, VIG_ATE, DISPOSITIVO, OBSERVACAO, INF_ADICIONAIS, ORIG_PROD)
                   VALUES(:P_ID_CENARIO, :P_COD_PROD, :P_CST, :P_NRSEQIMP, :P_BC_COMPOS, :P_ALIQUOTA, :P_P_RED_BC,". $sqlVigDe . $sqlVigAte . ", :P_DISPOSITIVO, :P_OBSERVACAO, :P_INFO_ADICIONAIS, :P_ORI_PROD)";
            }
    		
            return $this->entityManager->getConnection()->executeQuery($insert, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function insere_sys_material($cenario, $cod_prod, $descricao, $ean, $ncm, $ex_tipi, $ori_prod, $cfop, $cest){
        try {
            $params = array(
                'P_ID_CENARIO' => $cenario,
                'P_COD_PROD'   => $cod_prod,
                'P_DESCRICAO'  => $descricao,
                'P_EAN'        => $ean,
                'P_NCM'        => $ncm,
                'P_EX_TIPI'    => $ex_tipi,
                'P_ORI_PROD'   => $ori_prod,
                'P_CFOP'       => $cfop, 
                'P_CEST'       => $cest
            );
            
            $insert = "INSERT INTO SYS_MATERIAL(ID_CENARIO, COD_PROD, DESCRICAO, EAN, NCM, EX_TIPI, ORI_PROD, CFOP, CEST)
                       VALUES(:P_ID_CENARIO, :P_COD_PROD, :P_DESCRICAO, :P_EAN, :P_NCM, :P_EX_TIPI, :P_ORI_PROD, :P_CFOP, :P_CEST)";
    		
            return $this->entityManager->getConnection()->executeQuery($insert, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function busca_sys_cenario($cenario) {
        $sql = "SELECT * FROM SYS_CENARIO WHERE ID_CENARIO = :P_ID_CENARIO";
        
        $params = array(
            "P_ID_CENARIO" => $cenario  
        );
        
        return $this->entityManager->getConnection()->executeQuery($sql, $params)->fetchAll();
    }    
    
    public function busca_produto($cenario, $cod_prod, $ori_prod) {
        $sql = "SELECT
                    *
                FROM
                    SYS_MATERIAL
                WHERE
                    ID_CENARIO = :P_ID_CENARIO
                    AND COD_PROD = :P_COD_PROD
                    AND ORI_PROD = :P_ORI_PROD";
        
        $params = array(
            "P_ID_CENARIO"  => $cenario,
            "P_COD_PROD"    => $cod_prod,
            "P_ORI_PROD"    => $ori_prod
        );
        
        return $this->entityManager->getConnection()->executeQuery($sql, $params)->fetchAll();
    }
    
    public function update_sys_material($idcenario, $cod_prod, $descr, $ean, $ncm, $ex_tipi, $ori_prod, $cfop, $cest) {
        $sql = "UPDATE SYS_MATERIAL
                            SET DESCRICAO = :P_DESCRICAO,
                                EAN = :P_EAN,
                                NCM = :P_NCM,
                                EX_TIPI = :P_EX_TIPI,
                                ORI_PROD = :P_ORI_PROD,
                                CFOP = :P_CFOP,
                                CEST = :P_CEST
                            WHERE ID_CENARIO = :P_ID_CENARIO
                                AND COD_PROD = :P_COD_PROD
                                AND ORI_PROD = :P_ORI_PROD";
                        
        $params = array(
            'P_ID_CENARIO' => $idcenario,
            'P_COD_PROD'   => $cod_prod,
            'P_DESCRICAO'  => $descr,
            'P_EAN'        => $ean,
            'P_NCM'        => $ncm,
            'P_EX_TIPI'    => $ex_tipi,
            'P_ORI_PROD'   => $ori_prod,
            'P_CFOP'       => $cfop, 
            'P_CEST'       => $cest,
            'P_ORI_PROD'   => $ori_prod
        );
                
        return $this->entityManager->getConnection()->executeQuery($sql, $params);      
    }
    
    public function busca_icms($cenario, $cod_prod, $cst, $ori_prod) {
        $sql = "SELECT
                    TO_CHAR(VIG_DE, 'DD/MM/YYYY') AS VIG_DE,
                    TO_CHAR(VIG_ATE, 'DD/MM/YYYY') AS VIG_ATE,
                     TO_CHAR(VIG_DE_UF_DEST, 'DD/MM/YYYY') AS VIG_DE_UF_DEST,
                    TO_CHAR(VIG_ATE_UF_DEST, 'DD/MM/YYYY') AS VIG_ATE_UF_DEST
                FROM
                    SYS_ICMS
                WHERE
                    ID_CENARIO = :P_ID_CENARIO
                    AND COD_PROD = :P_COD_PROD
                    AND CST = :P_CST
                    AND ORIG_PROD = :P_ORI_PROD";
        
        $params = array(
            "P_ID_CENARIO"  => $cenario,
            "P_COD_PROD"    => $cod_prod,
            "P_CST"         => $cst,
            "P_ORI_PROD"    => $ori_prod
        );
        
        return $this->entityManager->getConnection()->executeQuery($sql, $params)->fetchAll();
    }
    
    public function busca_icmsst($cenario, $cod_prod, $ori_prod) {
        $sql = "SELECT
                    TO_CHAR(VIG_DE, 'DD/MM/YYYY') AS VIG_DE,
                    TO_CHAR(VIG_ATE, 'DD/MM/YYYY') AS VIG_ATE
                FROM
                    SYS_ICMSST
                WHERE
                    ID_CENARIO = :P_ID_CENARIO
                    AND COD_PROD = :P_COD_PROD
                    AND ORIG_PROD = :P_ORI_PROD";
        
        $params = array(
            "P_ID_CENARIO"  => $cenario,
            "P_COD_PROD"    => $cod_prod,
            "P_ORI_PROD"    => $ori_prod
        );
        
        return $this->entityManager->getConnection()->executeQuery($sql, $params)->fetchAll();
    }
    
    
    public function update_icms($imposto, $cenario, $cod_prod, $cst, $bc_compos, $aliquota, $p_red_bd, $vig_de, $vig_ate, $dispositivo, $observacao, $infoAdic,$paramsUfDest, $ori_prod){
        try {
           
            if($vig_de) {
                $date = new \DateTime($vig_de);
                $vig_de = $date->format('d/m/Y');
            }
            if($vig_ate) {
                $date = new \DateTime($vig_ate);
                $vig_ate = $date->format('d/m/Y');
            }

            $sqlVigDe = ($vig_de) ? "VIG_DE = TO_DATE(:P_VIG_DE, 'DD/MM/YYYY')," : "VIG_DE = :P_VIG_DE,";
            $sqlVigAte = ($vig_ate) ? "VIG_ATE = TO_DATE(:P_VIG_ATE, 'DD/MM/YYYY')," : "VIG_ATE = :P_VIG_ATE,";
        
           $params = array(
                'P_ID_CENARIO'  => $cenario,
                'P_COD_PROD'    => $cod_prod,
                'P_CST'         => $cst,
                'P_BC_COMPOS'   => $bc_compos,
                'P_ALIQUOTA'    => $aliquota,
                'P_P_RED_BC'    => $p_red_bd,
                'P_VIG_DE'      => $vig_de,
                'P_VIG_ATE'     => $vig_ate, 
                'P_DISPOSITIVO' => $dispositivo, 
                'P_OBSERVACAO'  => $observacao,
                "P_INFO_ADICIONAIS" => $infoAdic,
                "P_ORI_PROD"    => $ori_prod
            );
            
            if($paramsUfDest == null){
                 $sql = "UPDATE SYS_ICMS
                    SET
                        BC_COMPOS = :P_BC_COMPOS,
                        ALIQUOTA = :P_ALIQUOTA,
                        P_RED_BC = :P_P_RED_BC,".
                        $sqlVigDe.
                        $sqlVigAte.
                        "DISPOSITIVO = :P_DISPOSITIVO,
                        OBSERVACAO = :P_OBSERVACAO,
                        INF_ADICIONAIS = :P_INFO_ADICIONAIS
                    WHERE  ID_CENARIO = :P_ID_CENARIO
                        AND COD_PROD = :P_COD_PROD
                        AND CST = :P_CST
                        AND ORIG_PROD = :P_ORI_PROD";
               
            }else{  
                
                if($paramsUfDest[":P_VIG_DE_UF_DEST"]) {
                    $date = new \DateTime($paramsUfDest[":P_VIG_DE_UF_DEST"]);
                    $paramsUfDest[":P_VIG_DE_UF_DEST"] = $date->format('d/m/Y');
                }
                if($paramsUfDest[":P_VIG_ATE_UF_DEST"]) {
                    $date = new \DateTime($paramsUfDest[":P_VIG_ATE_UF_DEST"]);
                    $paramsUfDest[":P_VIG_ATE_UF_DEST"] = $date->format('d/m/Y');
                }
                
                $sqlVigDeUfDestino = ($paramsUfDest[":P_VIG_DE_UF_DEST"]) ? "VIG_DE_UF_DEST = TO_DATE(:P_VIG_DE_UF_DEST, 'DD/MM/YYYY')," : "VIG_DE_UF_DEST = :P_VIG_DE_UF_DEST,";
                $sqlVigAteUfDestino = ($paramsUfDest[":P_VIG_ATE_UF_DEST"]) ? "VIG_ATE_UF_DEST = TO_DATE(:P_VIG_ATE_UF_DEST, 'DD/MM/YYYY')," : "VIG_ATE_UF_DEST = :P_VIG_ATE_UF_DEST,";

             $sql = "UPDATE SYS_ICMS
                    SET
                        BC_COMPOS = :P_BC_COMPOS,
                        ALIQUOTA = :P_ALIQUOTA,
                        P_RED_BC = :P_P_RED_BC,".
                        $sqlVigDe.
                        $sqlVigAte.
                        "DISPOSITIVO = :P_DISPOSITIVO,
                        OBSERVACAO = :P_OBSERVACAO,
                        INF_ADICIONAIS = :P_INFO_ADICIONAIS,
                        CST_UF_DEST= :P_CST_UF_DEST,
                        ALIQ_UF_DEST = :P_ALIQ_UF_DEST,
                        BC_COMP_UF_DEST = :P_BC_COMP_UF_DEST,
                        BC_COMP_FCP_UF_DEST = :P_BC_COMP_FCP_UF_DEST,
                        RED_BC_ST_UF_DEST = :P_RED_BC_ST_UF_DEST,
                        ALIQ_INT_UF_DEST = :P_ALIQ_INT_UF_DEST,
                        FCP_UF_DEST = :P_FCP_UF_DEST,
                        PERC_PART_UF_DEST = :P_PERC_PART_UF_DEST,
                        VR_PAUTA_UF_DEST = :P_VR_PAUTA_UF_DEST,
                        UN_PAUTA_UF_DEST = :P_UN_PAUTA_UF_DEST,
                        GENERICO_UF_DEST = :P_GENERICO_UF_DEST,".
                        $sqlVigDeUfDestino.
                        $sqlVigAteUfDestino.
                        "DISP_LEGAL_UF_DEST = :P_DISP_LEGAL_UF_DEST,
                        OBSERV_UF_DEST = :P_OBSERV_UF_DEST 
                    WHERE  ID_CENARIO = :P_ID_CENARIO
                        AND COD_PROD = :P_COD_PROD
                        AND CST = :P_CST
                        AND ORIG_PROD = :P_ORI_PROD";
                        
            $params = array_merge($params,$paramsUfDest);
            
            }
            
            
            return $this->entityManager->getConnection()->executeQuery($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function update_icmsst($imposto, $cenario, $cod_prod, $cst, $bc_compos, $aliquota, $p_red_bd, $vig_de, $vig_ate, $dispositivo, $observacao, $ori_prod){
        try {
           
            if($vig_de) {
                $date = new \DateTime($vig_de);
                $vig_de = $date->format('d/m/Y');
            }
            if($vig_ate) {
                $date = new \DateTime($vig_ate);
                $vig_ate = $date->format('d/m/Y');
            }

            $sqlVigDe = ($vig_de) ? "VIG_DE = TO_DATE(:P_VIG_DE, 'DD/MM/YYYY')," : "VIG_DE = :P_VIG_DE,";
            $sqlVigAte = ($vig_ate) ? "VIG_ATE = TO_DATE(:P_VIG_ATE, 'DD/MM/YYYY')," : "VIG_ATE = :P_VIG_ATE,";
           
            $sql = "UPDATE SYS_ICMSST
                    SET
                        BC_COMPOSICAO = :P_BC_COMPOS,
                        ALIQUOTA_ST = :P_ALIQUOTA,
                        P_RED_BC_ST = :P_P_RED_BC,".
                        $sqlVigDe.
                        $sqlVigAte.
                        "DISPOSITIVO = :P_DISPOSITIVO,
                        OBSERVACAO = :P_OBSERVACAO
                    WHERE  ID_CENARIO = :P_ID_CENARIO
                        AND COD_PROD = :P_COD_PROD
                        AND ORIG_PROD = :P_ORI_PROD";

            $params = array(
                'P_ID_CENARIO'  => $cenario,
                'P_COD_PROD'    => $cod_prod,
                'P_BC_COMPOS'   => $bc_compos,
                'P_ALIQUOTA'    => $aliquota,
                'P_P_RED_BC'    => $p_red_bd,
                'P_VIG_DE'      => $vig_de,
                'P_VIG_ATE'     => $vig_ate, 
                'P_DISPOSITIVO' => $dispositivo, 
                'P_OBSERVACAO'  => $observacao,
                'P_ORI_PROD'    => $ori_prod
            );
            
            
            return $this->entityManager->getConnection()->executeQuery($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function busca_pis($cenario, $cod_prod, $cst, $ori_prod) {
        $sql = "SELECT
                    TO_CHAR(VIG_DE, 'DD/MM/YYYY') AS VIG_DE,
                    TO_CHAR(VIG_ATE, 'DD/MM/YYYY') AS VIG_ATE
                FROM
                    SYS_PIS
                WHERE
                    ID_CENARIO = :P_ID_CENARIO
                    AND COD_PROD = :P_COD_PROD
                    AND CST = :P_CST
                    AND ORIG_PROD = :P_ORI_PROD";
        
        $params = array(
            "P_ID_CENARIO"  => $cenario,
            "P_COD_PROD"    => $cod_prod,
            "P_CST"         => $cst,
            "P_ORI_PROD"    => $ori_prod
        );
        
        return $this->entityManager->getConnection()->executeQuery($sql, $params)->fetchAll();
    }
    
    public function update_pis($imposto, $cenario, $cod_prod, $cst, $bc_compos, $aliquota, $p_red_bd, $vig_de, $vig_ate, $dispositivo, $observacao,$infoAdic, $ori_prod){
        try {
           
            if($vig_de) {
                $date = new \DateTime($vig_de);
                $vig_de = $date->format('d/m/Y');
            }
            if($vig_ate) {
                $date = new \DateTime($vig_ate);
                $vig_ate = $date->format('d/m/Y');
            }
            
            $sqlVigDe = ($vig_de) ? "VIG_DE = TO_DATE(:P_VIG_DE, 'DD/MM/YYYY')," : "VIG_DE = :P_VIG_DE,";
            $sqlVigAte = ($vig_ate) ? "VIG_ATE = TO_DATE(:P_VIG_ATE, 'DD/MM/YYYY')," : "VIG_ATE = :P_VIG_ATE,";
           
            $sql = "UPDATE SYS_PIS
                    SET
                        BC_COMPOS = :P_BC_COMPOS,
                        ALIQUOTA = :P_ALIQUOTA,
                        P_RED_BC = :P_P_RED_BC,".
                        $sqlVigDe.
                        $sqlVigAte.
                        "DISPOSITIVO = :P_DISPOSITIVO,
                        OBSERVACAO = :P_OBSERVACAO,
                        INF_ADICIONAIS = :P_INFO_ADICIONAIS
                    WHERE  ID_CENARIO = :P_ID_CENARIO
                        AND COD_PROD = :P_COD_PROD
                        AND CST = :P_CST
                        AND ORIG_PROD = :P_ORI_PROD";
                        
                            
            $params = array(
                'P_ID_CENARIO'  => $cenario,
                'P_COD_PROD'    => $cod_prod,
                'P_CST'         => $cst,
                'P_BC_COMPOS'   => $bc_compos,
                'P_ALIQUOTA'    => $aliquota,
                'P_P_RED_BC'    => $p_red_bd,
                'P_VIG_DE'      => $vig_de,
                'P_VIG_ATE'     => $vig_ate, 
                'P_DISPOSITIVO' => $dispositivo, 
                'P_OBSERVACAO'  => $observacao,
                "P_INFO_ADICIONAIS" => $infoAdic,
                "P_ORI_PROD"    => $ori_prod
            );
            
            
            return $this->entityManager->getConnection()->executeQuery($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function busca_cofins($cenario, $cod_prod, $cst, $ori_prod) {
        $sql = "SELECT
                    TO_CHAR(VIG_DE, 'DD/MM/YYYY') AS VIG_DE,
                    TO_CHAR(VIG_ATE, 'DD/MM/YYYY') AS VIG_ATE
                FROM
                    SYS_COFINS
                WHERE
                    ID_CENARIO = :P_ID_CENARIO
                    AND COD_PROD = :P_COD_PROD
                    AND CST = :P_CST
                    AND ORIG_PROD = :P_ORI_PROD";
        
        $params = array(
            "P_ID_CENARIO"  => $cenario,
            "P_COD_PROD"    => $cod_prod,
            "P_CST"         => $cst,
            "P_ORI_PROD"    => $ori_prod
        );
        
        return $this->entityManager->getConnection()->executeQuery($sql, $params)->fetchAll();
    }
    
    public function update_cofins($imposto, $cenario, $cod_prod, $cst, $bc_compos, $aliquota, $p_red_bd, $vig_de, $vig_ate, $dispositivo, $observacao,$infoAdic, $ori_prod){
        try {
           
            if($vig_de) {
                $date = new \DateTime($vig_de);
                $vig_de = $date->format('d/m/Y');
            }
            if($vig_ate) {
                $date = new \DateTime($vig_ate);
                $vig_ate = $date->format('d/m/Y');
            }
            
            $sqlVigDe = ($vig_de) ? "VIG_DE = TO_DATE(:P_VIG_DE, 'DD/MM/YYYY')," : "VIG_DE = :P_VIG_DE,";
            $sqlVigAte = ($vig_ate) ? "VIG_ATE = TO_DATE(:P_VIG_ATE, 'DD/MM/YYYY')," : "VIG_ATE = :P_VIG_ATE,";
           
            $sql = "UPDATE SYS_COFINS
                    SET
                        BC_COMPOS = :P_BC_COMPOS,
                        ALIQUOTA = :P_ALIQUOTA,
                        P_RED_BC = :P_P_RED_BC,".
                        $sqlVigDe.
                        $sqlVigAte.
                        "DISPOSITIVO = :P_DISPOSITIVO,
                        OBSERVACAO = :P_OBSERVACAO,
                        INF_ADICIONAIS = :P_INFO_ADICIONAIS
                    WHERE  ID_CENARIO = :P_ID_CENARIO
                        AND COD_PROD = :P_COD_PROD
                        AND CST = :P_CST
                        AND ORIG_PROD = :P_ORI_PROD";
                        
                            
            $params = array(
                'P_ID_CENARIO'  => $cenario,
                'P_COD_PROD'    => $cod_prod,
                'P_CST'         => $cst,
                'P_BC_COMPOS'   => $bc_compos,
                'P_ALIQUOTA'    => $aliquota,
                'P_P_RED_BC'    => $p_red_bd,
                'P_VIG_DE'      => $vig_de,
                'P_VIG_ATE'     => $vig_ate, 
                'P_DISPOSITIVO' => $dispositivo, 
                'P_OBSERVACAO'  => $observacao,
                "P_INFO_ADICIONAIS" => $infoAdic,
                "P_ORI_PROD"    => $ori_prod
            );
            
            
            return $this->entityManager->getConnection()->executeQuery($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function busca_ipi($cenario, $cod_prod, $cst, $ori_prod) {
        $sql = "SELECT
                    TO_CHAR(VIG_DE, 'DD/MM/YYYY') AS VIG_DE,
                    TO_CHAR(VIG_ATE, 'DD/MM/YYYY') AS VIG_ATE
                FROM
                    SYS_IPI
                WHERE
                    ID_CENARIO = :P_ID_CENARIO
                    AND COD_PROD = :P_COD_PROD
                    AND CST = :P_CST
                    AND ORIG_PROD = :P_ORI_PROD";
        
        $params = array(
            "P_ID_CENARIO"  => $cenario,
            "P_COD_PROD"    => $cod_prod,
            "P_CST"         => $cst,
            "P_ORI_PROD"    => $ori_prod
        );
        
        return $this->entityManager->getConnection()->executeQuery($sql, $params)->fetchAll();
    }
    
    public function update_ipi($imposto, $cenario, $cod_prod, $cst, $bc_compos, $aliquota, $p_red_bd, $vig_de, $vig_ate, $dispositivo, $observacao,$infoAdic, $cenq, $ori_prod){
        try {
           
            if($vig_de) {
                $date = new \DateTime($vig_de);
                $vig_de = $date->format('d/m/Y');
            }
            if($vig_ate) {
                $date = new \DateTime($vig_ate);
                $vig_ate = $date->format('d/m/Y');
            }

            $sqlVigDe = ($vig_de) ? "VIG_DE = TO_DATE(:P_VIG_DE, 'DD/MM/YYYY')," : "VIG_DE = :P_VIG_DE,";
            $sqlVigAte = ($vig_ate) ? "VIG_ATE = TO_DATE(:P_VIG_ATE, 'DD/MM/YYYY')," : "VIG_ATE = :P_VIG_ATE,";
           
            $sql = "UPDATE SYS_IPI
                    SET
                        BC_COMPOS       = :P_BC_COMPOS,
                        ALIQUOTA        = :P_ALIQUOTA,
                        P_RED_BC        = :P_P_RED_BC,".
                        $sqlVigDe.
                        $sqlVigAte.
                        "DISPOSITIVO    = :P_DISPOSITIVO,
                        OBSERVACAO      = :P_OBSERVACAO,
                        CENQ            = :P_CENQ,
                        INF_ADICIONAIS = :P_INFO_ADICIONAIS
                    WHERE  ID_CENARIO = :P_ID_CENARIO
                        AND COD_PROD = :P_COD_PROD
                        AND CST = :P_CST
                        AND ORIG_PROD = :P_ORI_PROD";

            $params = array(
                'P_ID_CENARIO'  => $cenario,
                'P_COD_PROD'    => $cod_prod,
                'P_CST'         => $cst,
                'P_BC_COMPOS'   => $bc_compos,
                'P_ALIQUOTA'    => $aliquota,
                'P_P_RED_BC'    => $p_red_bd,
                'P_VIG_DE'      => $vig_de,
                'P_VIG_ATE'     => $vig_ate, 
                'P_DISPOSITIVO' => $dispositivo, 
                'P_OBSERVACAO'  => $observacao,
                'P_CENQ'        => $cenq,
                "P_INFO_ADICIONAIS" => $infoAdic,
                "P_ORI_PROD"    => $ori_prod
            );
            
            
            return $this->entityManager->getConnection()->executeQuery($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getSequencialImp($imposto, $cenario, $cod_prod) {
        $sql = "SELECT NVL(MAX(S.NRSEQIMP), 0) + 1 AS CODIGO FROM $imposto S WHERE S.ID_CENARIO = :P_ID_CENARIO AND S.COD_PROD = :P_COD_PROD";
       
        $params = array(
            "P_ID_CENARIO" => $cenario,
            "P_COD_PROD" => $cod_prod
        );
        $query = $this->connection->prepare($sql);
        $query->execute($params);

        return $query->fetch()["CODIGO"];
    }
   
    public function insere_sys_cenario($cenario, $dias_fut, $uf_origem, $uf_destino, $origem, $destinacao, $cod_natop, $mun_orig, $mun_dest, $cnae_dest, $ent_sai, $apelido){
        try {
            $params = array(
                'P_ID_CENARIO' => $cenario,
                'P_DIAS_FUT'   => $dias_fut,
                'P_UF_ORIGEM'  => $uf_origem,
                'P_UF_DESTINO' => $uf_destino,
                'P_ORIGEM'     => $origem,
                'P_DESTINACAO' => $destinacao,
                'P_COD_NATOP'  => $cod_natop,
                'P_MUN_ORIG'   => $mun_orig,
                'P_MUN_DEST'   => $mun_dest,
                'P_CNAE_DEST'  => $cnae_dest,
                'P_ENT_SAI'    => $ent_sai,
                'P_APELIDO'    => $apelido
            );
            
            $insert = "INSERT INTO SYS_CENARIO(ID_CENARIO, DIAS_FUT, UF_ORIGEM, UF_DESTINO, ORIGEM, DESTINACAO, COD_NATOP, MUN_ORIG, MUN_DEST, CNAE_DEST, ENT_SAI, APELIDO)
                       VALUES(:P_ID_CENARIO, :P_DIAS_FUT, :P_UF_ORIGEM, :P_UF_DESTINO, :P_ORIGEM, :P_DESTINACAO, :P_COD_NATOP, :P_MUN_ORIG, :P_MUN_DEST, :P_CNAE_DEST, :P_ENT_SAI, :P_APELIDO)";
    		
            return $this->entityManager->getConnection()->executeQuery($insert, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function insere_log_importa_regrafis($cenario, $cod_prod, $erro){
        try {
            $params = array(
                'P_ID_CENARIO' => $cenario,
                'P_COD_PROD'   => $cod_prod,
                'P_ERRO'       => $erro
            );
            
            $insert = "INSERT INTO LOG_IMPORTA_REGRAFIS(ID_CENARIO, COD_PROD, ERRO)
                       VALUES(:P_ID_CENARIO, :P_COD_PROD, :P_ERRO)";
    		
            return $this->entityManager->getConnection()->executeQuery($insert, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function existeProduto($codProd) {
        $sql = "SELECT CDPRODUTO FROM PRODUTO WHERE CDARVPROD = :P_CDPRODUTO";
        
        $params = array(
            "P_CDPRODUTO" => $codProd    
        );
        
        return $this->entityManager->getConnection()->executeQuery($sql, $params)->fetch();
    }

    public function getDadosAcesso() {
        $sql = "SELECT * FROM SYS_DADOSACESSO";
        
        return $this->entityManager->getConnection()->executeQuery($sql)->fetch();
    }
    
    public function atualizaSysDadosAcesso($nrseqdadoac, $id_cenario, $cod_prod, $ponteiro_atualizacao){
        try {
            $params = array(
                'P_NRSEQDADOAC' => $nrseqdadoac,
                'P_ID_CENARIO'  => $id_cenario,
                'P_COD_PROD'    => $cod_prod,
                'P_PONTATU'     => $ponteiro_atualizacao
            );
            
            $insert = "UPDATE SYS_DADOSACESSO SET ULTPROD = :P_COD_PROD, ULTCENARIO = :P_ID_CENARIO, PONTEIRO_ATUALIZACAO = :P_PONTATU WHERE NRSEQDADOAC = :P_NRSEQDADOAC";
    		
            return $this->entityManager->getConnection()->executeQuery($insert, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
}